@@ -9,7 +9,7 @@ Perl::Critic::Policy::Tics::ProhibitLongLines - 80 x 40 for life!
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -21,7 +21,7 @@ Width.  Going over that occasionally is okay, but only once in a while.
 use Perl::Critic::Utils;
 use base qw(Perl::Critic::Policy);
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 my $DESCRIPTION = q{Document contains overly-long lines.};
 my $EXPLANATION = q{Keep lines to about eighty columns wide.};
@@ -33,7 +33,7 @@ sub applies_to       { 'PPI::Document' }
 sub violates {
   my ($self, $elem, $doc) = @_;
 
-  return unless $elem->serialize =~ /^.{100,}?$/sm;
+  return unless $elem->serialize =~ /^.{100,}?$/m;
 
   # Must be a violation...
   return $self->violation($DESCRIPTION, $EXPLANATION, $doc);
